{
    package GCLang::FR;
    
    use utf8;
###################################################
#
#  Copyright 2005 Tian
#
#  This file is part of GCfilms.
#
#  GCfilms is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2 of the License, or
#  (at your option) any later version.
#
#  GCfilms is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with GCfilms; if not, write to the Free Software
#  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
###################################################

    use strict;
    use base 'Exporter';

    our @EXPORT = qw(%lang);

    our %lang = (

        'LangName' => 'Français',
        
        'Separator' => ' : ',
        
        'Warning' => '<b>Attention</b> :
        
Les informations récupérées depuis des sites Internet
(grâce aux modules de recherche) ne peuvent servir que
pour une <b>utilisation personnelle</b> dans un cadre privé.

Vous ne pouvez en aucune manière les redistribuer sans
l\'<b>accord préalable</b> des sites concernés.

Vous pourrez à tout instant connaître le site d\'où
proviennent les informations d\'un film en cliquant sur
le <b>bouton situé en dessous de sa fiche</b>.',

        'AllMoviesFiltered' => 'Aucun film ne correspond aux critères de filtrage',
        
        'InstallDirInfo' => 'Installation dans ',
        'InstallMandatory' => 'Composants obligatoires',
        'InstallOptional' => 'Composants optionnels',
        'InstallErrorMissing' => 'Erreur : Les composants Perl suivants doivent être installés : ',
        'InstallPrompt' => 'Répertoire de base pour l\'installation [/usr/local] : ',
        'InstallEnd' => 'Fin de l\'installation',
        'InstallNoError' => 'Aucune erreur',
        'InstallLaunch' => 'Pour utiliser l\'application, lancez ',
        'InstallDirectory' => 'Répertoire de base',
        'InstallTitle' => 'Installation de GCfilms',
        'InstallDependencies' => 'Dépendances',
        'InstallPath' => 'Chemin',
        'InstallOptions' => 'Options',
        'InstallSelectDirectory' => 'Choisissez le répertoire de base pour l\'installation',
        'InstallWithClean' => 'Effacer précédents fichiers situés au même emplacement',
       	'InstallWithMenu' => 'Ajouter GCfilms au menu des applications',
       	'InstallNoPermission' => 'Erreur: Vous n\'avez pas la permission d\'écrire dans le répertoire sélectionné',
        'InstallMissingMandatory' => 'Des dépendances obligatoires sont manquantes. Vous ne pourrez pas installer GCfilms tant qu\'elles ne seront pas installées.',
        'InstallMissingOptional' => 'Quelques dépendances facultatives sont manquantes. Elles sont listées ci-dessous. GCfilms peut être installé mais certaines fonctionnalités ne seront pas présentes.',
        'InstallMissingNone' => 'Aucune dépendance n\'est manquante. Vous pouvez poursuivre l\'installation de GCfilms.',
        'InstallOK' => 'OK',
        'InstallMissing' => 'Manquant',
        'InstallMissingFor' => 'Manquant pour',

        'SplashInit' => 'Initialisation',
        'SplashLoad' => 'Chargement des films',
        'SplashDone' => 'Prêt',

        'RemoveConfirm' => 'Voulez-vous vraiment supprimer ce film ?',
        'NewMovie' => 'Nouveau film',
        'NewMovieTooltip' => 'Ajouter un nouveau film',
        'NoMovieFound' => 'Aucun film ne correspond. Voulez-vous tenter une recherche sur un autre site ?',
        'OpenList' => 'Quelle liste de films ouvrir ?',
        'SaveList' => 'Dans quel fichier enregistrer ?',
        'SaveListTooltip' => 'Enregistrer la liste courante',
        'SaveCurrentList' => 'Vous devez d\'abord choisir dans quel fichier sauver la liste courante ?',
        'Movies' => 'Films',
        'PreferencesTooltip' => 'Changer vos préférences',
        'ViewTooltip' => 'Changer le type de liste',
        'PlayTooltip' => 'Lancer la lecture de la vidéo associée au film',
        
        'StatusSearch' => 'Recherche en cours...',
        'StatusGetInfo' => 'Récupération des informations...',
        'StatusGetImage' => 'Téléchargement de l\'image...',
        
		'SaveError' => 'Impossible de sauver la liste de films. Vérifiez les permissions et la place disponible sur le disque.',
		'OpenError' => 'Impossible d\'ouvrir la liste de films. Vérifiez les permissions.',
		'ImageError' => 'Le répertoire choisi pour stocker les images n\'est pas correct. Veuillez en choisir un autre.',
        'OptionsCreationError'=> 'Impossible de créer le fichier d\'options : ',
        'OptionsOpenError'=> 'Impossible d\'ouvrir le fichier d\'options : ',
        'OptionsSaveError'=> 'Impossible d\'enregistrer le fichier d\'options : ',

        'RandomTooltip' => 'Que vais-je regarder ce soir ?',
        'RandomError'=> 'Vous n\'avez pas de film non vu',
        'RandomEnd'=> 'Il n\'y a plus d\'autre film',
        'RandomNextTip'=> 'Proposition suivante',
        'RandomOkTip'=> 'Accepter ce film',
        
        'AboutTitle' => 'A propos de GCfilms',
        'AboutDesc' => 'Gtk2 Catalogue de films',
        'AboutVersion' => 'Version',
        'AboutTeam' => 'Equipe',
        'AboutWho' => 'Tian : Gestionnaire du projet, Programmeur
MeV : Programmeur
Christophe Z : Programmeur
Adolfo González : Programmeur

Jason Day : Contributeur
Gabriel Meier : Contributeur

Dab : Contributeur
rootII : Contributeur
VFRMania : Contributeur',
        'AboutLicense' => 'Distribué selon les termes de la GNU GPL
Logos Copyright le Spektre
http://le-spektre.org',
        'AboutTranslation' => 'Traduction française par Tian',
        'AboutDesign' => 'Logo et webdesign par le Spektre',
        
        'ToolbarRandom' => 'Ce soir',
        
        'ResultsTitle' => 'Choisissez un film',
        'ResultsMovieTitle' => 'Titre',
        'ResultsMovieYear' => 'Année',
        'ResultsMovieDirector' => 'Réalisateur',
        'ResultsMovieActors' => 'Acteurs',
        'ResultsNextTip' => 'Rechercher sur le site suivant',

        'OptionsTitle' => 'Préférences',
        'OptionsBrowser' => 'Navigateur web',
        'OptionsPlayer' => 'Lecteur de vidéos',
        'OptionsImages' => 'Répertoire images',
        'OptionsUseRelativePaths' => 'Utiliser des chemins relatifs pour les images',
        'OptionsOrder' => 'Disposition',
        'OptionsStatus' => 'Afficher la barre d\'état en bas de la fenêtre',
        'OptionsUrlPicture' => 'Afficher le logo du site sur le bouton permettant d\'ouvrir la page d\'un film',
        'OptionsWarning' => 'Attention : Les changements effectués dans cet onglet ne seront pris en compte qu\'après un redémarrage de l\'application',
        'OptionsTabs' => 'Onglets',
        'OptionsAllInOne' => 'Une seule page',
        'OptionsCompact' => 'Compact',
        'OptionsReadOnly' => 'Lecture seule',
        'OptionsWebSite' => 'Site Web GCfilms',
        'OptionsRemoveConfirm' => 'Demander confirmation avant la suppression',
        'OptionsAutoSave' => 'Sauvegarde automatique de la liste de films',
        'OptionsSplash' => 'Afficher l\'écran de démarrage',
        'OptionsImagesTitle' => 'Choisissez un répertoire',
        'OptionsBrowserTitle' => 'Choisissez le programme à utiliser',
		'OptionsPlugins' => 'Site où récupérer les fiches',
		'OptionsAskPlugins' => 'Demander (Tous les sites)',
		'OptionsPluginsMulti' => 'Plusieurs sites',
		'OptionsPluginsMultiAsk' => 'Demander (Certains sites)',
		'OptionsPluginsList' => 'Définir la liste',		
        'OptionsAskImport' => 'Choisir les champs à importer',
		'OptionsProxy' => 'Utiliser un proxy',
        'OptionsMain' => 'Principal',
        'OptionsLang' => 'Langue',
        'OptionsPaths' => 'Chemins',
        'OptionsInternet' => 'Internet',
        'OptionsConveniences' => 'Options',
        'OptionsDisplay' => 'Affichage',
        'OptionsToolbar' => 'Barre d\'outils',
        'OptionsToolbars' => {0 => 'Aucune', 1 => 'Petite', 2 => 'Grande'},
        'OptionsToolbarPosition' => 'Position',
        'OptionsToolbarPositions' => {0 => 'Haut', 1 => 'Bas', 2 => 'Gauche', 3 => 'Droite'},
        'OptionsView' => 'Affichage des films',
        'OptionsViews' => {0 => 'Texte', 1 => 'Image', 2 => 'Détaillée'},
        'OptionsColumns' => 'Colonnes',
        'OptionsMailer' => 'Méthode d\'envoi d\'e-mails',
        'OptionsSMTP' => 'Serveur',
        'OptionsFrom' => 'E-mail expéditeur',
        'OptionsTransform' => 'Mettre à la fin des titres les articles',
        'OptionsArticles' => 'Articles (Séparés par des virgules)',
        'OptionsFormats' => 'Type de supports (Séparés par des virgules)',
        'OptionsSearchStop' => 'Une recherche peut être arrêtée',
        'OptionsAlwaysOriginal' => 'Utiliser le titre principal comme titre original si non présent',
		'OptionsHistory' => 'Taille de l\'historique',
		'OptionsClearHistory' => 'Purger l\'historique',
		'OptionsStyle' => 'Thème',
        'OptionsDontAsk' => 'Ne plus demander',

        'ImagesOptionsButton' => 'Réglages',
        'ImagesOptionsTitle' => 'Réglages pour la liste d\'images',
        'ImagesOptionsSelectColor' => 'Choisissez une couleur',
        'ImagesOptionsBg' => 'Fond',
        'ImagesOptionsBgPicture' => 'Utiliser une image de fond',
        'ImagesOptionsFg'=> 'Selection',
        'ImagesOptionsBgTooltip' => 'Changer la couleur de fond',
        'ImagesOptionsFgTooltip'=> 'Changer la couleur de la sélection',
        'ImagesOptionsSizeLabel' => 'Taille',
        'ImagesOptionsSizeList' => {0 => 'Minuscule', 1 => 'Petit', 2 => 'Moyen', 3 => 'Grand', 4 => 'Enorme'},
        'ImagesOptionsSizeTooltip' => 'Selectionnez la taille pour les images',

        'DetailedOptionsTitle' => 'Réglages pour la liste détaillée',
        'DetailedOptionsImageSize' => 'Taille des images',
        'DetailedOptionsGroupMovies' => 'Regrouper les films de la même série',
		'DetailedOptionsFields' => 'Choisir les champs à afficher',

        'ExtractButton' => 'Informations',
        'ExtractTitle' => 'Informations du fichier vidéo',
        'ExtractSize' => 'Dimensions',
        'ExtractLength' => 'Durée (minutes)',
        'ExtractType' => 'Format vidéo',
        'ExtractAudioEncoding' => 'Format audio',
        'ExtractImport' => 'Utiliser les valeurs',

        'ExportTitle' => 'Exporter la liste de films',
        'ExportFilter' => 'Exporter seulement les films affichés',
        'ImportListTitle' => 'Importer une autre liste de films',
        'ImportExportFile' => 'Fichier',
        'ImportExportSave' => 'Choisissez le fichier à utiliser',
        'ImportExportFieldsUnused' => 'Champs inutilisés',
        'ImportExportFieldsUsed' => 'Champs utilisés',
        'ImportExportFieldsFill' => 'Tous les champs',
        'ImportExportFieldsClear' => 'Aucun champ',
        'ImportExportFieldsEmpty' => 'Au moins un champ doit être spécifié',
        'ImportExportFileEmpty' => 'Un nom de fichier doit être spécifié',
        'ExportFieldsTitle' => 'Champs à exporter',
        'ExportFieldsTip' => 'Choisir les champs devant être exportés',
        'ImportFieldsTitle' => 'Champs à importer',
        'ImportFieldsTip' => 'Choisir les champs devant être importés',
        'ImportNewList' => 'Créer une nouvelle liste',
        'ImportCurrentList' => 'Ajouter à la liste courante',
        
        'FileOverwrite' => 'Ce fichier existe. Voulez vous le remplacer ?',

        'PanelSearchButton' => 'Télécharger',
        'PanelSearchTip' => 'Rechercher les informations concernant le film dont le titre a été saisi',
        'PanelSeenYes' => 'Film vu',
        'PanelSeenNo' => 'Film non vu',
        'PanelLanguages' => 'Langues',
        'PanelEncoding' => 'Encodage',
        'PanelImageTip' => 'Cliquez sur l\'image pour en choisir une autre. Clic droit pour plus d\'options.',
        'PanelImageTitle' => 'Sélectionnez une image',
        'PanelTrailerTitle' => 'Sélectionnez un fichier',
        'PanelInfoFrame' => 'Informations',
        'PanelAgeUnknown' => 'Inconnu',
        'PanelAgeNone' => 'Aucune restriction',
        'PanelAgeParent' => 'Accord parental',
        'PanelNobody' => 'Personne',
        'PanelUnknown' => 'Inconnu',
        'PanelLendedYes' => 'Prêté',
        'PanelLendedNo' => 'Disponible',
        'PanelLendDateSelect' => '_Changer la date',
        'PanelReturned' => 'Film _rendu',
        'PanelRemove' =>'S_upprimer',
        'PanelClear' =>'_Vider',
        'PanelReturnDate' => 'Date de retour',
        'PanelWeb' => 'Voir la fiche Internet',
        'PanelWebTip' => 'Voir la fiche du film sur Internet',
        'PanelRemoveTip' => 'Supprimer le film affiché ci-dessus',
        'PanelMovieInfo' => 'Fiche du film',
        'PanelPrivateInfo' => 'Détails',
        'PanelLendInfo' => 'Emprunts',

        'MenuNewList' => 'Nouvelle _liste de films',
        'MenuLend' => 'Voir les films empruntés',
        'MenuHistory' => 'Fichiers récemment ouverts',
        'MenuExport' => '_Exporter',
        'MenuImport' => '_Importer',
        'MenuMovies' => '_Fichier',
        'MenuSearchMovies' => 'Re_chercher',
        'MenuSearchSelectedMovies' => 'Rechercher dans les films affichés',
        'MenuSearchAllMovies' => 'Rechercher dans tous les films',
        'MenuViewAllMovies' => 'Voir _tous les films',
        'MenuAllMovies' => 'Tous les films',
        'MenuNotSeen' => 'Films non vus',
        'MenuSeenOrNot' => 'Films _vus ou non',
        'MenuAllCategories' => 'Toutes les catégories',
        'MenuCategories' => 'Films de la caté_gorie',
        'MenuRating' => 'Films é_valués',
        'MenuAllRating' => 'Toutes les notes',
        'MenuChooseRating' => 'Notes au moins égales à...',
        'MenuBorrowing' => 'Films _disponibles ou non',
        'MenuBorrowed' => 'Films empruntés',
        'MenuNotBorrowed' => 'Films disponibles',
        'MenuAge' => 'Films pour quel public',
        'MenuAgeNone' => 'Tous publics',
        'MenuAgeParent' => 'Avec _accord parental',
        'MenuAgeLess' => 'D\'un âge _spécifié...',
        'MenuEdit'  => '_Edition',
   	    'MenuDuplicate' => '_Dupliquer le film',
        'MenuEditDeleteCurrent' => 'Su_pprimer le film courant',
        'MenuEditLockMovies' => 'Verroui_ller les informations',
        'MenuDisplay' => 'Fil_tres',
        'MenuConfiguration' => '_Configuration',
        'MenuDisplayOptions' => '_Informations à afficher',
        'MenuBorrowers' => '_Emprunteurs',
        'MenuGenresConversion' => 'Conversions de _genres',
        'MenuRename' => '_Renommer un genre',
        'MenuAbout' => 'A _propos de GCfilms',
        'MenuHelp' => '_?',
        'MenuNewWindow' => 'Afficher le film dans une nouvelle fenêtre',
                
        'ToolbarAll' => 'Voir tous',
        'ToolbarAllTooltip' => 'Afficher tous les films',

        'RatingTitle' => 'Note minimale',
        'RatingLabel' => 'Seront uniquement affichés les films dont la note est supérieure ou égale à la valeur suivante',

        'AgeTitle' => 'Age du public',
        'AgeLabel' => 'Seront uniquement affichés les films pouvant convenir à un public de l\'âge indiqué',

        'StatusMovies' => 'Films',
        
        'PluginsTitle' => 'Chercher un film',
        'PluginsFrame' => 'Site où rechercher',
        'PluginsLogo' => 'Logo',
        'PluginsName' => 'Nom',
        'PluginsAuthor' => 'Auteur',
        'PluginsLang' => 'Langue',
        'PluginsUseSite' => 'Utiliser le site sélectionné pour les futures recherches',
        
        'BorrowersTitle' => 'Configuration des emprunteurs',
        'BorrowersName' => 'Nom',
        'BorrowersEmail' => 'E-mail',
        'BorrowersAdd' => 'Ajouter',
        'BorrowersRemove' => '_Supprimer',
        'BorrowersEdit' => '_Modifier',
        'BorrowersTemplate' => 'Modèle d\'e-mail',
        'BorrowersSubject' => 'Titre du mail : ',
        'BorrowersNotice1' => '%1 sera remplacé par le nom de l\'emprunteur',
        'BorrowersNotice2' => '%2 sera remplacé par le titre du film',
        'BorrowersNotice3' => '%3 sera remplacé par la date de l\'emprunt',
      
        'BorrowedTitle' => 'Films empruntés',
        'BorrowedMovie' => 'Film',
        'BorrowedName' => 'Emprunteur',
        'BorrowedDate' => 'Depuis le',
        
        'MailTitle' => '_Envoyer un e-mail',
        'MailFrom' => 'De : ',
        'MailTo' => 'A : ',
        'MailSubject' => 'Objet : ',
        'MailSmtpError' => 'Problème de connexion au serveur SMTP',
        'MailSendmailError' => 'Problème au lancement de sendmail',
                
        'SearchTooltip' => 'Rechercher dans tous les films',
        'SearchTitle' => 'Recherche de films',
        'SearchMovieTitle' => 'Titre contient ',
        'SearchRating' => 'Note au moins égales à ',
        'SearchDirector' => 'Réalisateur',
        'SearchActors' => 'Acteurs (séparés par une virgule)',
        'SearchType' => 'Genre',
        'SearchSeen' => 'Film déjà vu',
        'SearchUndef' => 'Sans importance',
        'SearchSeenYes' => 'Oui',
        'SearchSeenNo' => 'Non',
        'SearchAge' => 'Age du public',
        'SearchYear' => 'Année entre',
        'SearchYearBetween' => 'et',
        
        'RenameTitle' => 'Renommer une catégorie',
        'RenameOld' => 'Nom actuel',
        'RenameNew' => 'Nouveau nom',
        
        'ImportWindowTitle' => 'Choisir les champs à importer',
        'ImportViewPicture' => 'Voir l\'image',
        'ImportSelectAll' => 'Tout sélectionner',
        'ImportSelectNone' => 'Ne rien sélectionner',
        
        'ExportTarGzInfo' => 'L\'archive se trouve dans le fichier : ',

        'ExportHTMLWithJS' => 'Utiliser du Javascript',
        'ExportHTMLFileTemplate' => 'Modèle :',
        'ExportHTMLPreview' => 'Aperçu',
        'ExportHTMLNoPreview' => 'Aucun aperçu disponible',
        'ExportHTMLTitle' => 'Titre de la page',
        'ExportHTMLInfoFile' => 'La liste se trouve dans le fichier : ',
        'ExportHTMLInfoDir' => 'Les images se trouvent dans : ',
        'ExportHTMLHeightimg' => 'Hauteur en pixel de l\'image à exporter : ',
        'ExportHTMLOpenFileInBrowser' => 'Ouvrir le fichier généré dans le navigateur web',
        'ExportHTMLNote' => 'Liste générée avec <a href="http://home.gna.org/gcfilms/">GCfilms</a>',
        'ExportHTMLInputTitle' => 'Entrez le texte à rechercher',
        'ExportHTMLSearchType1' => 'Titre seulement',
        'ExportHTMLSearchType2' => 'Toutes les informations',
        'ExportHTMLSearchButton' => 'Rechercher',
        'ExportHTMLSearchTitle' => 'Afficher seulement les films correspondant aux critères précédents',
        'ExportHTMLAllButton' => 'Tous',
        'ExportHTMLAllTitle' => 'Afficher tous les films',
        'ExportHTMLExpand' => 'Tout développer',
        'ExportHTMLExpandTitle' => 'Afficher les informations de tous les films',
        'ExportHTMLCollapse' => 'Tout réduire',
        'ExportHTMLCollapseTitle' => 'Masquer les informations de tous les films',
        'ExportHTMLBorrowed' => 'Emprunté par : ',
        'ExportHTMLNotBorrowed' => 'Disponible',
        'ExportHTMLTop' => 'Haut',

        'ExportSQLWithPictures' => 'Copier les images dans un sous-répertoire',
        'ExportSQLWithDrop' => 'Inclure une instruction DROP',
        'ExportSQLWithCreate' => 'Inclure une instruction CREATE',
        'ExportSQLTableName' => 'Nom de la table',
        'ExportSQLInfoFile' => 'Fichier SQL : ',
        
        'ExportXMLModels' => 'Modèle à utiliser',
        'ExportXMLUseModel' => 'Spécifié dans la zone texte',
        'ExportXMLUseFile' => 'Spécifié dans un fichier',
        'ExportXMLModelFile' => 'Fichier modèle',
        'ExportXMLModelText' => 'Texte du modèle',
        
        'ExportCSVHeader' => 'Inclure les noms des champs au début',
        'ExportCSVSeparator' => 'Séparateur',
        'ExportCSVReplacement' => 'Remplacer le séparateur par',
        
        'ImportCSVHeader' => 'Ignorer la première ligne',
        
        'ImportListName' => 'Liste de titres',
        'ImportListPlugin' => 'Site à utiliser',
        'ImportListUseFirst' => 'Choisir le 1er si plusieurs résultats',
        'ImportListCommentAuto' => 'Film importé automatiquement.',
        'ImportListCommentSite' => 'Site web : ',
        'ImportListCommentTitle' => 'Titre : ',
        
        'ImportTellicoNotVideo' => 'Le fichier n\'est pas un catalogue Tellico de videos',
        
        'MultiSiteTitle' => 'Sites où rechercher',
        'MultiSiteUnused' => 'Modules non utilisés',
        'MultiSiteUsed' => 'Modules à utiliser',
        'MultiSiteLang' => 'Remplir la liste avec les modules français',
        'MultiSiteEmptyError' => 'Vous avez une liste de sites vide',
        'MultiSiteClear' => 'Vider la liste',
        
        'FieldsList' => {
            id => 'Informations : Id',
            title => 'Informations : Titre',
            date => 'Informations : Date de sortie',
            time => 'Informations : Durée',
            director => 'Informations : Réalisateur',
            nat => 'Informations : Nationalité',
            age => 'Informations : Age minimum',
            type => 'Informations : Genres',
            image => 'Informations : Image',
            orig => 'Informations : Titre original',
            actors => 'Informations : Acteurs',
            comment => 'Personnel : Commentaires',
            synopsis => 'Informations : Synopsis',
            seen => 'Personnel : Film déjà vu',
            number => 'Support : Nombre',
            rating => 'Personnel : Note',
            format => 'Support : Format',
            url => 'Informations : URL de la fiche',
            place => 'Support : Emplacement',
            video => 'Support : Format vidéo',
            trailer => 'Détails : Fichier vidéo',
            collection => 'Détails : Série',
            rank => 'Détails : Rang',
            audio => 'Langues : Audio',
            subt => 'Langues : Sous-titres',
            borrower => 'Emprunt : Emprunteur',
            lendDate => 'Emprunt : Date d\'emprunt',
            history => 'Emprunt : Historique des emprunts',
        },
        
        'DisplayOptionsTitle' => 'Eléments à afficher',
        'DisplayOptionsAll' => 'Tout sélectionner',
        'DisplayOptionsMain' => 'Principaux éléments',
        'DisplayOptionsActions' => 'Boutons sous les fiches',
        'DisplayOptionsSearch' => 'Bouton recherche',
        
        'GenresTitle' => 'Conversions de genres',
        'GenresCategoryName' => 'Genre à utiliser',
        'GenresCategoryMembers' => 'Genres à remplacer',
        'GenresLoad' => 'Charger une liste prédéfinie',
        'GenresExport' => 'Exporter la liste dans un fichier',
        'GenresModify' => 'Changer la conversion',
    );
}
1;
